@@ -20,10 +20,12 @@ except ImportError:
         raise
 
 
-version = "0.4.1"
-version_info = (0, 4, 1, 0)
+version = "0.4.2"
+version_info = (0, 4, 2, 0)
+
 
 class Connection(object):
+
     """A lightweight wrapper around MySQLdb DB-API connections.
 
     The main value we provide is wrapping rows in a dict/object so that
@@ -39,15 +41,18 @@ class Connection(object):
     We explicitly set the timezone to UTC and the character encoding to
     UTF-8 on all connections to avoid time zone and encoding errors.
     """
-    def __init__(self, host, database, user=None, password=None, auto_commit=True,
-                 use_charset='utf8',max_idle_time=7 * 3600, connect_timeout=0):
+
+    def __init__(
+        self, host, database, user=None, password=None, auto_commit=True,
+        use_charset='utf8', max_idle_time=7 * 3600, connect_timeout=0):
         self.host = host
         self.database = database
         self.max_idle_time = float(max_idle_time)
         self.auto_commit = auto_commit
 
         args = dict(conv=CONVERSIONS, use_unicode=True, charset=use_charset,
-                    db=database, init_command="",
+                    db=database,
+                    # init_command="",
                     connect_timeout=connect_timeout, sql_mode="TRADITIONAL")
         if user is not None:
             args["user"] = user
@@ -246,7 +251,9 @@ class Connection(object):
 
 
 class Row(dict):
+
     """A dict that allows for object-like property access syntax."""
+
     def __getattr__(self, name):
         try:
             return self[name]
@@ -264,7 +271,8 @@ if MySQLdb is not None:
         field_types.append(FIELD_TYPE.VARCHAR)
 
     for field_type in field_types:
-        CONVERSIONS[field_type] = [(FLAG.BINARY, str)] + CONVERSIONS[field_type]
+        CONVERSIONS[field_type] = [
+            (FLAG.BINARY, str)] + CONVERSIONS[field_type]
 
     # Alias some common MySQL exceptions
     IntegrityError = MySQLdb.IntegrityError
